Invoice - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Invoice

Company

Client

# Invoice INV/001/15

| Product | Qnt | Unit | Amount
--- | --- | --- | --- | ---
1 | Logo Creation Logo and business cards design | 1 | $1.800,00 | $1.800,00
2 | Online Store Design & Development Design/Development for all popular modern browsers | 1 | $20.000,00 | $20.000,00
3 | App Design Promotional mobile application | 1 | $3.200,00 | $3.200,00
Subtotal | $25.000,00
Vat Rate | 20%
Vat Due | $5.000,00
Total Due | $30.000,00

Thank you very much for doing business with us. We look forward to working with you again!